@@ -152,6 +152,26 @@ impl<'stack> LocalStack<'stack> {
             error_oops_err(outer, 0xdead_000f, &e, meta)
         })
     }
+
+    /// Fetches a local variable
+    ///
+    /// # Errors
+    /// if the variable isn't known
+    pub fn get_mut<O>(
+        &mut self,
+        idx: usize,
+        outer: &O,
+        mid: usize,
+        meta: &NodeMetas,
+    ) -> Result<&mut Option<Value<'stack>>>
+    where
+        O: BaseExpr,
+    {
+        self.values.get_mut(idx).ok_or_else(|| {
+            let e = format!("Unknown local variable: `{}`", meta.name_dflt(mid));
+            error_oops_err(outer, 0xdead_000f, &e, meta)
+        })
+    }
 }
 
 /// The type of an aggregation
@@ -1440,6 +1460,7 @@ where
 }
 
 #[inline]
+// ALLOW: https://github.com/tremor-rs/tremor-runtime/issues/1029
 #[allow(mutable_transmutes, clippy::transmute_ptr_to_ptr)]
 fn set_local_shadow<'run, 'event, 'script, Expr>(
     outer: &'script Expr,
@@ -1454,8 +1475,7 @@ where
     'event: 'run,
 {
     use std::mem;
-    // This is icky do we want it?
-    // it is only used
+    // ALLOW: https://github.com/tremor-rs/tremor-runtime/issues/1029
     let local: &'run mut LocalStack<'event> = unsafe { mem::transmute(local) };
     local.values.get_mut(idx).map_or_else(
         || {
