@@ -169,7 +169,7 @@ where
                             } else if let Some(_f) = r.as_f64() {
                                 out.push_str("42");
                             } else {
-                                out.push_str(r.encode().as_str());
+                                out.push_str(crate::utils::sorted_serialize(&r)?.as_str());
                             };
                         }
                     }
@@ -177,8 +177,6 @@ where
                 Ok(Cow::Owned(out.into()))
             }
             ImutExprInt::Recur(Recur { exprs, argc, .. }) => {
-                #[allow(mutable_transmutes, clippy::transmute_ptr_to_ptr)]
-                let local: &'run mut LocalStack<'event> = unsafe { mem::transmute(local) };
                 // We need to pre calculate that to ensure that we don't overwrite
                 // local variables that are not used
                 let mut next = Vec::with_capacity(*argc);
@@ -188,6 +186,10 @@ where
                         next.push((i, r.into_owned()));
                     }
                 }
+                // ALLOW: https://github.com/tremor-rs/tremor-runtime/issues/1030
+                #[allow(mutable_transmutes, clippy::transmute_ptr_to_ptr)]
+                // ALLOW: https://github.com/tremor-rs/tremor-runtime/issues/1030
+                let local: &'run mut LocalStack<'event> = unsafe { mem::transmute(local) };
                 for (i, v) in next.drain(..) {
                     if let Some(loc) = local.values.get_mut(i) {
                         *loc = Some(v);
@@ -423,6 +425,7 @@ where
                     }
                 }
                 ClauseGroup::SearchTree { tree, rest, .. } => {
+                    // ALLOW: https://github.com/tremor-rs/tremor-runtime/issues/1034
                     let target: &Value<'script> = unsafe { mem::transmute(target) };
                     if let Some((_, l)) = tree.get(&target) {
                         return Self::execute_effectors(opts, env, event, state, meta, local, l);
@@ -441,6 +444,7 @@ where
                                 }
                             }
                             ClauseGroup::SearchTree { tree, rest, .. } => {
+                                // ALLOW: https://github.com/tremor-rs/tremor-runtime/issues/1034
                                 let target: &Value<'script> = unsafe { mem::transmute(target) };
                                 if let Some((_, l)) = tree.get(&target) {
                                     return Self::execute_effectors(
@@ -737,7 +741,6 @@ where
             })
     }
 
-    #[allow(mutable_transmutes, clippy::transmute_ptr_to_ptr)]
     fn emit_aggr(
         &'script self,
         opts: ExecOpts,
@@ -760,6 +763,9 @@ where
             .ok_or_else(|| {
                 error_oops_err(self, 0xdead_0012, "Unknown aggregate function", &env.meta)
             })?;
+        // ALLOW: https://github.com/tremor-rs/tremor-runtime/issues/1035
+        #[allow(mutable_transmutes, clippy::transmute_ptr_to_ptr)]
+        // ALLOW: https://github.com/tremor-rs/tremor-runtime/issues/1035
         let invocable: &mut TremorAggrFnWrapper = unsafe { mem::transmute(inv) };
         let r = invocable.emit().map(Cow::Owned).map_err(|e| {
             let r: Option<&Registry> = None;
